KoltchinskiiSakhanenko: Koltchinskii and Sakhanenko's test for elliptical symmetry
Description
Test for elliptical symmetry.
Usage
KoltchinskiiSakhanenko(X, R = 1000, nJobs = -1)
Arguments
X
A numeric matrix.
R
The number of bootstrap replicates.
nJobs
The number of CPU cores used for the calculation. The default value -1 indicates that all cores except one are used.
Value
An object of class "htest" containing the following components:
statistic
The value of the test statistic.
pvalue
The p-value of the test.
alternative
A character string describing the alternative hypothesis.
method
A character string indicating what type of test was performed.
Background
Koltchinskii and Sakhanenko (2000) proposed a class of omnibus bootstrap tests for elliptical symmetry
that are affine invariant and consistent against any fixed alternative. This test is based on spherical harmonics.
References
Koltchinskii, V., & Sakhanenko, L., (2000). Testing for ellipsoidal symmetry of a multivariate distribution. High Dimensional Probability II, 493-510, Springer.
Sakhanenko, L., (2008). Testing for ellipsoidal symmetry: A comparison study. Computational Statistics & Data Analysis, 53(2), 565-581.
# NOT RUN {## sepal width and length of the versicolor subset of the Iris dataX = datasets::iris[51:100,1:2]
KoltchinskiiSakhanenko(X, R = 10, nJobs=2)
# }