PseudoGaussian: Pseudo-Gaussian test for elliptical symmetry
Description
Tests for elliptical symmetry: specified and unspecified location.
Usage
PseudoGaussian(X, location = NA)
Arguments
X
A numeric matrix.
location
A vector of location parameters.
Value
An object of class "htest" containing the following components:
statistic
The value of the test statistic.
pvalue
The p-value of the test.
alternative
A character string describing the alternative hypothesis.
method
A character string indicating what type of test was performed.
Background
Pseudo-Gaussian tests for elliptical symmetry are based on Le Cam<U+2019>s theory of statistical experiments.
They are most efficient against a multivariate form of Fechner-type asymmetry.
These tests require finite moments of order 4 and they have a simple asymptotic chi-squared distribution
under the null hypothesis of ellipticity.
Details
Note that location allows the user to specify the known location.
The default is set to NA which means that the unspecified location test will be performed unless the user specifies location.
References
Cassart, D., Hallin, M. & Paindaveine, D., (2008). Optimal detection of Fechner-asymmetry. Journal of Statistical Planning and Inference, 138, 2499-2525.
Cassart, D., (2007). Optimal tests for symmetry. Ph.D. thesis, Univ. libre de Bruxelles, Brussels.