An object of class "htest" containing the following components:
statistic
The value of the test statistic.
pvalue
The p-value of the test.
alternative
A character string describing the alternative hypothesis.
method
A character string indicating what type of test was performed.
Background
A Wald-type test for elliptical symmetry based on fourth moments.
It compares the sample fourth moments with the expected theoretical ones under ellipticity.
Being based on fourth-order moments, the test is very simple to use but requires moments of order 8.
It has an asymptotic chi-squared distribution under the null hypothesis of ellipticity.
References
Schott, James R., (2002). Testing for elliptical symmetry in covariance-matrix-based analyses. Statistics & Probability Letters, 60(4), 395-404.