X and location are the only input arguments for the specified location test.
The default value for location is set to NA which implies that the unspecified location test will be performed
unless the user specifies location.
For the unspecified location test, besides the data matrix X, the input arguments are f and param.
The f argument is a string that specifies the type of the radial density upon which the test is based.
Currently supported options are: "t" for the radial density of the multivariate t distribution,
"logistic" for the multivariate logistic and "powerExp" for the radial density of the multivariate power-exponential distribution.
Note that the default is set to "t".
The role of the param argument is as follows.
If f = "t" then param denotes the degrees of freedom of the multivariate t distribution.
Given that the default radial density is "t", it follows that the default value of param
represents the degrees of freedom of the multivariate t distribution and it is set to 4.
Note also that the degrees of freedom have to be greater than 2.
If f = "powerExp" then param denotes the kurtosis parameter. In that case the value of param
has to be different from 1, because for the multivariate power exponential distribution, a kurtosis parameter equal to 1 corresponds
to the multivariate Gaussian distribution (the Gaussian f is excluded due to a singular Fisher information matrix).
The default value is set to 0.5.